summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/lineedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/lineedit.h')
-rw-r--r--kalarm/lib/lineedit.h15
1 files changed, 8 insertions, 7 deletions
diff --git a/kalarm/lib/lineedit.h b/kalarm/lib/lineedit.h
index 5d36de3c..0da53683 100644
--- a/kalarm/lib/lineedit.h
+++ b/kalarm/lib/lineedit.h
@@ -43,16 +43,17 @@
class LineEdit : public KLineEdit
{
Q_OBJECT
+ TQ_OBJECT
public:
/** Types of drag and drop content which will be accepted.
- * @li Text - the line edit tqcontains general text. It accepts text, a URL
+ * @li Text - the line edit contains general text. It accepts text, a URL
* or an email from KMail (the subject line is used). If multiple
* URLs or emails are dropped, only the first is used; the
* rest are ignored.
- * @li Url - the line edit tqcontains a URL. It accepts text or a URL. If
+ * @li Url - the line edit contains a URL. It accepts text or a URL. If
* multiple URLs are dropped, only the first URL is used; the
* rest are ignored.
- * @li Emails - the line edit tqcontains email addresses. It accepts text,
+ * @li Emails - the line edit contains email addresses. It accepts text,
* mailto: URLs, emails from KMail (the From address is used)
* or vcard data (e.g. from KAddressBook). If multiple emails
* are dropped, only the first is used; the rest are ignored.
@@ -61,15 +62,15 @@ class LineEdit : public KLineEdit
enum Type { Text, Url, Emails };
/** Constructor.
* @param type The content type for the line edit.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- explicit LineEdit(Type type, TQWidget* parent = 0, const char* name = 0);
+ explicit LineEdit(Type type, TQWidget* tqparent = 0, const char* name = 0);
/** Constructs a line edit whose content type is Text.
* @param parent The parent object of this widget.
* @param name The name of this widget.
*/
- explicit LineEdit(TQWidget* parent = 0, const char* name = 0);
+ explicit LineEdit(TQWidget* tqparent = 0, const char* name = 0);
/** Prevents the line edit's contents being selected when the widget receives focus. */
void setNoSelect() { mNoSelect = true; }
/** Sets whether the cursor should be set at the beginning or end of the text when
@@ -61,15 +62,15 @@ class LineEdit : public KLineEdit
/** Constructor.
* @param type The content type for the line edit.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
@@ -61,15 +62,15 @@ class LineEdit : public KLineEdit
/** Constructs a line edit whose content type is Text.
- * @param parent The parent object of this widget.
+ * @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/